Class: Google::Cloud::DataCatalog::Lineage::V1::EntityReference

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb

Overview

The soft reference to everything you can attach a lineage event to.

Instance Attribute Summary collapse

Instance Attribute Details

#field::Array<::String>

Returns Optional. Field path within the entity. Each nesting level should be a separate value in the repeated field. The order matters. Must be empty for asset level lineage

For example to address "salary.net" subfield where "salary" is a column and "net" is a proto field two values in the field should be reported, the first is "salary" and the second is "net".

Each field length is limited to 500 characters. Maximum supported nesting level is 20.

Returns:

  • (::Array<::String>)

    Optional. Field path within the entity. Each nesting level should be a separate value in the repeated field. The order matters. Must be empty for asset level lineage

    For example to address "salary.net" subfield where "salary" is a column and "net" is a proto field two values in the field should be reported, the first is "salary" and the second is "net".

    Each field length is limited to 500 characters. Maximum supported nesting level is 20.



194
195
196
197
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 194

class EntityReference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#fully_qualified_name::String

Returns Required. Fully Qualified Name (FQN) of the entity.

Returns:



194
195
196
197
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 194

class EntityReference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end