Class: Google::Cloud::DataCatalog::Lineage::V1::ListLineageEventsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb

Overview

Request message for ListLineageEvents.

Instance Attribute Summary collapse

Instance Attribute Details

#page_size::Integer

Returns Optional. The maximum number of lineage events to return.

The service may return fewer events than this value. If unspecified, at most 50 events are returned. The maximum value is 100; values greater than 100 are cut to 100.

Returns:

  • (::Integer)

    Optional. The maximum number of lineage events to return.

    The service may return fewer events than this value. If unspecified, at most 50 events are returned. The maximum value is 100; values greater than 100 are cut to 100.



552
553
554
555
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 552

class ListLineageEventsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. The page token received from a previous ListLineageEvents call. Specify it to get the next page.

When paginating, all other parameters specified in this call must match the parameters of the call that provided the page token.

Returns:

  • (::String)

    Optional. The page token received from a previous ListLineageEvents call. Specify it to get the next page.

    When paginating, all other parameters specified in this call must match the parameters of the call that provided the page token.



552
553
554
555
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 552

class ListLineageEventsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The name of the run that owns the collection of lineage events to get.

Returns:

  • (::String)

    Required. The name of the run that owns the collection of lineage events to get.



552
553
554
555
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 552

class ListLineageEventsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end