Class: Google::Cloud::DataCatalog::Lineage::V1::ListProcessesResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb

Overview

Response message for ListProcesses.

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token::String

Returns The token to specify as page_token in the next call to get the next page. If this field is omitted, there are no subsequent pages.

Returns:

  • (::String)

    The token to specify as page_token in the next call to get the next page. If this field is omitted, there are no subsequent pages.



384
385
386
387
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 384

class ListProcessesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#processes::Array<::Google::Cloud::DataCatalog::Lineage::V1::Process>

Returns The processes from the specified project and location.

Returns:



384
385
386
387
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 384

class ListProcessesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end