Class: Google::Cloud::DataCatalog::Lineage::V1::ListRunsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb

Overview

Request message for ListRuns.

Instance Attribute Summary collapse

Instance Attribute Details

#page_size::Integer

Optional. The maximum number of runs to return. The service may return fewer than this value. If unspecified, at most 50 runs are returned. The maximum value is 100; values greater than 100 are cut to 100.

Returns:

  • (::Integer)

    Optional. The maximum number of runs to return. The service may return fewer than this value. If unspecified, at most 50 runs are returned. The maximum value is 100; values greater than 100 are cut to 100.



471
472
473
474
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 471

class ListRunsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. The page token received from a previous ListRuns call. Specify it to get the next page.

When paginating, all other parameters specified in this call must match the parameters of the call that provided the page token.

Returns:

  • (::String)

    Optional. The page token received from a previous ListRuns call. Specify it to get the next page.

    When paginating, all other parameters specified in this call must match the parameters of the call that provided the page token.



471
472
473
474
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 471

class ListRunsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The name of process that owns this collection of runs.

Returns:

  • (::String)

    Required. The name of process that owns this collection of runs.



471
472
473
474
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 471

class ListRunsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end