Class: Google::Cloud::DataCatalog::Lineage::V1::ListRunsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb

Overview

Response message for ListRuns.

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token::String

Returns The token to specify as page_token in the next call to get the next page. If this field is omitted, there are no subsequent pages.

Returns:

  • (::String)

    The token to specify as page_token in the next call to get the next page. If this field is omitted, there are no subsequent pages.



485
486
487
488
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 485

class ListRunsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#runs::Array<::Google::Cloud::DataCatalog::Lineage::V1::Run>

Returns The runs from the specified project and location.

Returns:



485
486
487
488
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 485

class ListRunsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end