Class: Google::Cloud::DataCatalog::Lineage::V1::Origin

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb

Overview

Origin of a process.

Defined Under Namespace

Modules: SourceType

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns If the source_type isn't CUSTOM, the value of this field should be a Google Cloud resource name of the system, which reports lineage. The project and location parts of the resource name must match the project and location of the lineage resource being created. Examples:

  • {source_type: COMPOSER, name: "projects/foo/locations/us/environments/bar"}
  • {source_type: BIGQUERY, name: "projects/foo/locations/eu"}
  • {source_type: CUSTOM, name: "myCustomIntegration"}.

Returns:

  • (::String)

    If the source_type isn't CUSTOM, the value of this field should be a Google Cloud resource name of the system, which reports lineage. The project and location parts of the resource name must match the project and location of the lineage resource being created. Examples:

    • {source_type: COMPOSER, name: "projects/foo/locations/us/environments/bar"}
    • {source_type: BIGQUERY, name: "projects/foo/locations/eu"}
    • {source_type: CUSTOM, name: "myCustomIntegration"}


807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 807

class Origin
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Type of the source of a process.
  module SourceType
    # Source is Unspecified
    SOURCE_TYPE_UNSPECIFIED = 0

    # A custom source
    CUSTOM = 1

    # BigQuery
    BIGQUERY = 2

    # Data Fusion
    DATA_FUSION = 3

    # Composer
    COMPOSER = 4

    # Looker Studio
    LOOKER_STUDIO = 5

    # Dataproc
    DATAPROC = 6

    # Vertex AI
    VERTEX_AI = 7

    # Dataflow
    DATAFLOW = 8

    # Looker Core
    LOOKER_CORE = 9
  end
end

#source_type::Google::Cloud::DataCatalog::Lineage::V1::Origin::SourceType

Returns Type of the source.

Use of a source_type other than CUSTOM for process creation or updating is highly discouraged. It might be restricted in the future without notice. There will be increase in cost if you use any of the source types other than CUSTOM.

Returns:

  • (::Google::Cloud::DataCatalog::Lineage::V1::Origin::SourceType)

    Type of the source.

    Use of a source_type other than CUSTOM for process creation or updating is highly discouraged. It might be restricted in the future without notice. There will be increase in cost if you use any of the source types other than CUSTOM.



807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 807

class Origin
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Type of the source of a process.
  module SourceType
    # Source is Unspecified
    SOURCE_TYPE_UNSPECIFIED = 0

    # A custom source
    CUSTOM = 1

    # BigQuery
    BIGQUERY = 2

    # Data Fusion
    DATA_FUSION = 3

    # Composer
    COMPOSER = 4

    # Looker Studio
    LOOKER_STUDIO = 5

    # Dataproc
    DATAPROC = 6

    # Vertex AI
    VERTEX_AI = 7

    # Dataflow
    DATAFLOW = 8

    # Looker Core
    LOOKER_CORE = 9
  end
end