Class: Google::Cloud::DataCatalog::Lineage::V1::SearchLineageStreamingRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb

Overview

Request message for SearchLineageStreaming.

Defined Under Namespace

Modules: EntitySet, SearchDirection Classes: RootCriteria, SearchFilters, SearchLimits

Instance Attribute Summary collapse

Instance Attribute Details

#direction::Google::Cloud::DataCatalog::Lineage::V1::SearchLineageStreamingRequest::SearchDirection

Returns Required. Direction of the search.



907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 907

class SearchLineageStreamingRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Filters for the search.
  # @!attribute [rw] dependency_types
  #   @return [::Array<::Google::Cloud::DataCatalog::Lineage::V1::DependencyType>]
  #     Optional. Types of dependencies between entities to retrieve.
  #     If unspecified, all dependency types are returned.
  # @!attribute [rw] entity_set
  #   @return [::Google::Cloud::DataCatalog::Lineage::V1::SearchLineageStreamingRequest::EntitySet]
  #     Optional. Entity set restriction. If unspecified, the method returns all
  #     entities.
  # @!attribute [rw] time_range
  #   @return [::Google::Type::Interval]
  #     Optional. Time interval to search for lineage. If unspecified, all
  #     lineage is returned. Currently, at most one of `start_time` and
  #     `end_time` can be set.
  class SearchFilters
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Limits for the search results.
  # @!attribute [rw] max_depth
  #   @return [::Integer]
  #     Optional. The maximum depth of the search. The default value is 5 and
  #     maximum value is 100.
  # @!attribute [rw] max_results
  #   @return [::Integer]
  #     Optional. The maximum number of links to return in the response. The
  #     default value is 1_000 and the maximum value is 10_000.
  # @!attribute [rw] max_process_per_link
  #   @return [::Integer]
  #     Optional. The maximum number of processes to return per link. The default
  #     value is 0 and the maximum value is 100. If this value is non-zero, the
  #     response will contain process names for the links. To retrieve full
  #     process details in the response, include `links.processes.process` in the
  #     [FieldMask](https://developers.google.com/workspace/docs/api/how-tos/field-masks#read_with_a_field_mask).
  class SearchLimits
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Criteria for the root of the search.
  # @!attribute [rw] entities
  #   @return [::Google::Cloud::DataCatalog::Lineage::V1::MultipleEntityReference]
  #     Optional. The entities to initiate the search from. Entities can be
  #     specified by FQN only, or by FQN and field. To search by FQN and all
  #     available fields for that FQN, use the wildcard `*` as the field value.
  class RootCriteria
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Direction of the search.
  module SearchDirection
    # Direction is unspecified.
    SEARCH_DIRECTION_UNSPECIFIED = 0

    # Retrieve links that lead from the specified asset to downstream assets.
    DOWNSTREAM = 1

    # Retrieve links that lead from upstream assets to the specified asset.
    UPSTREAM = 2
  end

  # Entity set restriction.
  module EntitySet
    # The entity set is unspecified. Returns all the data.
    ENTITY_SET_UNSPECIFIED = 0

    # Returns entities with only FQN specified. For example, entities with the
    # `field` field set are not returned.
    ENTITIES = 1
  end
end

#filters::Google::Cloud::DataCatalog::Lineage::V1::SearchLineageStreamingRequest::SearchFilters

Returns Optional. Filters for the search.



907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 907

class SearchLineageStreamingRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Filters for the search.
  # @!attribute [rw] dependency_types
  #   @return [::Array<::Google::Cloud::DataCatalog::Lineage::V1::DependencyType>]
  #     Optional. Types of dependencies between entities to retrieve.
  #     If unspecified, all dependency types are returned.
  # @!attribute [rw] entity_set
  #   @return [::Google::Cloud::DataCatalog::Lineage::V1::SearchLineageStreamingRequest::EntitySet]
  #     Optional. Entity set restriction. If unspecified, the method returns all
  #     entities.
  # @!attribute [rw] time_range
  #   @return [::Google::Type::Interval]
  #     Optional. Time interval to search for lineage. If unspecified, all
  #     lineage is returned. Currently, at most one of `start_time` and
  #     `end_time` can be set.
  class SearchFilters
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Limits for the search results.
  # @!attribute [rw] max_depth
  #   @return [::Integer]
  #     Optional. The maximum depth of the search. The default value is 5 and
  #     maximum value is 100.
  # @!attribute [rw] max_results
  #   @return [::Integer]
  #     Optional. The maximum number of links to return in the response. The
  #     default value is 1_000 and the maximum value is 10_000.
  # @!attribute [rw] max_process_per_link
  #   @return [::Integer]
  #     Optional. The maximum number of processes to return per link. The default
  #     value is 0 and the maximum value is 100. If this value is non-zero, the
  #     response will contain process names for the links. To retrieve full
  #     process details in the response, include `links.processes.process` in the
  #     [FieldMask](https://developers.google.com/workspace/docs/api/how-tos/field-masks#read_with_a_field_mask).
  class SearchLimits
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Criteria for the root of the search.
  # @!attribute [rw] entities
  #   @return [::Google::Cloud::DataCatalog::Lineage::V1::MultipleEntityReference]
  #     Optional. The entities to initiate the search from. Entities can be
  #     specified by FQN only, or by FQN and field. To search by FQN and all
  #     available fields for that FQN, use the wildcard `*` as the field value.
  class RootCriteria
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Direction of the search.
  module SearchDirection
    # Direction is unspecified.
    SEARCH_DIRECTION_UNSPECIFIED = 0

    # Retrieve links that lead from the specified asset to downstream assets.
    DOWNSTREAM = 1

    # Retrieve links that lead from upstream assets to the specified asset.
    UPSTREAM = 2
  end

  # Entity set restriction.
  module EntitySet
    # The entity set is unspecified. Returns all the data.
    ENTITY_SET_UNSPECIFIED = 0

    # Returns entities with only FQN specified. For example, entities with the
    # `field` field set are not returned.
    ENTITIES = 1
  end
end

#limits::Google::Cloud::DataCatalog::Lineage::V1::SearchLineageStreamingRequest::SearchLimits

Returns Optional. Limits for the search.



907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 907

class SearchLineageStreamingRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Filters for the search.
  # @!attribute [rw] dependency_types
  #   @return [::Array<::Google::Cloud::DataCatalog::Lineage::V1::DependencyType>]
  #     Optional. Types of dependencies between entities to retrieve.
  #     If unspecified, all dependency types are returned.
  # @!attribute [rw] entity_set
  #   @return [::Google::Cloud::DataCatalog::Lineage::V1::SearchLineageStreamingRequest::EntitySet]
  #     Optional. Entity set restriction. If unspecified, the method returns all
  #     entities.
  # @!attribute [rw] time_range
  #   @return [::Google::Type::Interval]
  #     Optional. Time interval to search for lineage. If unspecified, all
  #     lineage is returned. Currently, at most one of `start_time` and
  #     `end_time` can be set.
  class SearchFilters
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Limits for the search results.
  # @!attribute [rw] max_depth
  #   @return [::Integer]
  #     Optional. The maximum depth of the search. The default value is 5 and
  #     maximum value is 100.
  # @!attribute [rw] max_results
  #   @return [::Integer]
  #     Optional. The maximum number of links to return in the response. The
  #     default value is 1_000 and the maximum value is 10_000.
  # @!attribute [rw] max_process_per_link
  #   @return [::Integer]
  #     Optional. The maximum number of processes to return per link. The default
  #     value is 0 and the maximum value is 100. If this value is non-zero, the
  #     response will contain process names for the links. To retrieve full
  #     process details in the response, include `links.processes.process` in the
  #     [FieldMask](https://developers.google.com/workspace/docs/api/how-tos/field-masks#read_with_a_field_mask).
  class SearchLimits
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Criteria for the root of the search.
  # @!attribute [rw] entities
  #   @return [::Google::Cloud::DataCatalog::Lineage::V1::MultipleEntityReference]
  #     Optional. The entities to initiate the search from. Entities can be
  #     specified by FQN only, or by FQN and field. To search by FQN and all
  #     available fields for that FQN, use the wildcard `*` as the field value.
  class RootCriteria
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Direction of the search.
  module SearchDirection
    # Direction is unspecified.
    SEARCH_DIRECTION_UNSPECIFIED = 0

    # Retrieve links that lead from the specified asset to downstream assets.
    DOWNSTREAM = 1

    # Retrieve links that lead from upstream assets to the specified asset.
    UPSTREAM = 2
  end

  # Entity set restriction.
  module EntitySet
    # The entity set is unspecified. Returns all the data.
    ENTITY_SET_UNSPECIFIED = 0

    # Returns entities with only FQN specified. For example, entities with the
    # `field` field set are not returned.
    ENTITIES = 1
  end
end

#locations::Array<::String>

Returns Required. The locations to search in.

Returns:

  • (::Array<::String>)

    Required. The locations to search in.



907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 907

class SearchLineageStreamingRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Filters for the search.
  # @!attribute [rw] dependency_types
  #   @return [::Array<::Google::Cloud::DataCatalog::Lineage::V1::DependencyType>]
  #     Optional. Types of dependencies between entities to retrieve.
  #     If unspecified, all dependency types are returned.
  # @!attribute [rw] entity_set
  #   @return [::Google::Cloud::DataCatalog::Lineage::V1::SearchLineageStreamingRequest::EntitySet]
  #     Optional. Entity set restriction. If unspecified, the method returns all
  #     entities.
  # @!attribute [rw] time_range
  #   @return [::Google::Type::Interval]
  #     Optional. Time interval to search for lineage. If unspecified, all
  #     lineage is returned. Currently, at most one of `start_time` and
  #     `end_time` can be set.
  class SearchFilters
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Limits for the search results.
  # @!attribute [rw] max_depth
  #   @return [::Integer]
  #     Optional. The maximum depth of the search. The default value is 5 and
  #     maximum value is 100.
  # @!attribute [rw] max_results
  #   @return [::Integer]
  #     Optional. The maximum number of links to return in the response. The
  #     default value is 1_000 and the maximum value is 10_000.
  # @!attribute [rw] max_process_per_link
  #   @return [::Integer]
  #     Optional. The maximum number of processes to return per link. The default
  #     value is 0 and the maximum value is 100. If this value is non-zero, the
  #     response will contain process names for the links. To retrieve full
  #     process details in the response, include `links.processes.process` in the
  #     [FieldMask](https://developers.google.com/workspace/docs/api/how-tos/field-masks#read_with_a_field_mask).
  class SearchLimits
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Criteria for the root of the search.
  # @!attribute [rw] entities
  #   @return [::Google::Cloud::DataCatalog::Lineage::V1::MultipleEntityReference]
  #     Optional. The entities to initiate the search from. Entities can be
  #     specified by FQN only, or by FQN and field. To search by FQN and all
  #     available fields for that FQN, use the wildcard `*` as the field value.
  class RootCriteria
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Direction of the search.
  module SearchDirection
    # Direction is unspecified.
    SEARCH_DIRECTION_UNSPECIFIED = 0

    # Retrieve links that lead from the specified asset to downstream assets.
    DOWNSTREAM = 1

    # Retrieve links that lead from upstream assets to the specified asset.
    UPSTREAM = 2
  end

  # Entity set restriction.
  module EntitySet
    # The entity set is unspecified. Returns all the data.
    ENTITY_SET_UNSPECIFIED = 0

    # Returns entities with only FQN specified. For example, entities with the
    # `field` field set are not returned.
    ENTITIES = 1
  end
end

#parent::String

Returns Required. The project and location to initiate the search from.

Returns:

  • (::String)

    Required. The project and location to initiate the search from.



907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 907

class SearchLineageStreamingRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Filters for the search.
  # @!attribute [rw] dependency_types
  #   @return [::Array<::Google::Cloud::DataCatalog::Lineage::V1::DependencyType>]
  #     Optional. Types of dependencies between entities to retrieve.
  #     If unspecified, all dependency types are returned.
  # @!attribute [rw] entity_set
  #   @return [::Google::Cloud::DataCatalog::Lineage::V1::SearchLineageStreamingRequest::EntitySet]
  #     Optional. Entity set restriction. If unspecified, the method returns all
  #     entities.
  # @!attribute [rw] time_range
  #   @return [::Google::Type::Interval]
  #     Optional. Time interval to search for lineage. If unspecified, all
  #     lineage is returned. Currently, at most one of `start_time` and
  #     `end_time` can be set.
  class SearchFilters
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Limits for the search results.
  # @!attribute [rw] max_depth
  #   @return [::Integer]
  #     Optional. The maximum depth of the search. The default value is 5 and
  #     maximum value is 100.
  # @!attribute [rw] max_results
  #   @return [::Integer]
  #     Optional. The maximum number of links to return in the response. The
  #     default value is 1_000 and the maximum value is 10_000.
  # @!attribute [rw] max_process_per_link
  #   @return [::Integer]
  #     Optional. The maximum number of processes to return per link. The default
  #     value is 0 and the maximum value is 100. If this value is non-zero, the
  #     response will contain process names for the links. To retrieve full
  #     process details in the response, include `links.processes.process` in the
  #     [FieldMask](https://developers.google.com/workspace/docs/api/how-tos/field-masks#read_with_a_field_mask).
  class SearchLimits
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Criteria for the root of the search.
  # @!attribute [rw] entities
  #   @return [::Google::Cloud::DataCatalog::Lineage::V1::MultipleEntityReference]
  #     Optional. The entities to initiate the search from. Entities can be
  #     specified by FQN only, or by FQN and field. To search by FQN and all
  #     available fields for that FQN, use the wildcard `*` as the field value.
  class RootCriteria
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Direction of the search.
  module SearchDirection
    # Direction is unspecified.
    SEARCH_DIRECTION_UNSPECIFIED = 0

    # Retrieve links that lead from the specified asset to downstream assets.
    DOWNSTREAM = 1

    # Retrieve links that lead from upstream assets to the specified asset.
    UPSTREAM = 2
  end

  # Entity set restriction.
  module EntitySet
    # The entity set is unspecified. Returns all the data.
    ENTITY_SET_UNSPECIFIED = 0

    # Returns entities with only FQN specified. For example, entities with the
    # `field` field set are not returned.
    ENTITIES = 1
  end
end

#root_criteria::Google::Cloud::DataCatalog::Lineage::V1::SearchLineageStreamingRequest::RootCriteria

Returns Required. Criteria for the root of the search.

Returns:



907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 907

class SearchLineageStreamingRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Filters for the search.
  # @!attribute [rw] dependency_types
  #   @return [::Array<::Google::Cloud::DataCatalog::Lineage::V1::DependencyType>]
  #     Optional. Types of dependencies between entities to retrieve.
  #     If unspecified, all dependency types are returned.
  # @!attribute [rw] entity_set
  #   @return [::Google::Cloud::DataCatalog::Lineage::V1::SearchLineageStreamingRequest::EntitySet]
  #     Optional. Entity set restriction. If unspecified, the method returns all
  #     entities.
  # @!attribute [rw] time_range
  #   @return [::Google::Type::Interval]
  #     Optional. Time interval to search for lineage. If unspecified, all
  #     lineage is returned. Currently, at most one of `start_time` and
  #     `end_time` can be set.
  class SearchFilters
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Limits for the search results.
  # @!attribute [rw] max_depth
  #   @return [::Integer]
  #     Optional. The maximum depth of the search. The default value is 5 and
  #     maximum value is 100.
  # @!attribute [rw] max_results
  #   @return [::Integer]
  #     Optional. The maximum number of links to return in the response. The
  #     default value is 1_000 and the maximum value is 10_000.
  # @!attribute [rw] max_process_per_link
  #   @return [::Integer]
  #     Optional. The maximum number of processes to return per link. The default
  #     value is 0 and the maximum value is 100. If this value is non-zero, the
  #     response will contain process names for the links. To retrieve full
  #     process details in the response, include `links.processes.process` in the
  #     [FieldMask](https://developers.google.com/workspace/docs/api/how-tos/field-masks#read_with_a_field_mask).
  class SearchLimits
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Criteria for the root of the search.
  # @!attribute [rw] entities
  #   @return [::Google::Cloud::DataCatalog::Lineage::V1::MultipleEntityReference]
  #     Optional. The entities to initiate the search from. Entities can be
  #     specified by FQN only, or by FQN and field. To search by FQN and all
  #     available fields for that FQN, use the wildcard `*` as the field value.
  class RootCriteria
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Direction of the search.
  module SearchDirection
    # Direction is unspecified.
    SEARCH_DIRECTION_UNSPECIFIED = 0

    # Retrieve links that lead from the specified asset to downstream assets.
    DOWNSTREAM = 1

    # Retrieve links that lead from upstream assets to the specified asset.
    UPSTREAM = 2
  end

  # Entity set restriction.
  module EntitySet
    # The entity set is unspecified. Returns all the data.
    ENTITY_SET_UNSPECIFIED = 0

    # Returns entities with only FQN specified. For example, entities with the
    # `field` field set are not returned.
    ENTITIES = 1
  end
end