Module: Google::Cloud::DataCatalog::Lineage::V1::SearchLineageStreamingRequest::SearchDirection

Defined in:
proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb

Overview

Direction of the search.

Constant Summary collapse

SEARCH_DIRECTION_UNSPECIFIED =

Direction is unspecified.

0
DOWNSTREAM =

Retrieve links that lead from the specified asset to downstream assets.

1
UPSTREAM =

Retrieve links that lead from upstream assets to the specified asset.

2