Class: Google::Cloud::DataCatalog::Lineage::V1::SearchLineageStreamingRequest::SearchLimits

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb

Overview

Limits for the search results.

Instance Attribute Summary collapse

Instance Attribute Details

#max_depth::Integer

Returns Optional. The maximum depth of the search. The default value is 5 and maximum value is 100.

Returns:

  • (::Integer)

    Optional. The maximum depth of the search. The default value is 5 and maximum value is 100.



946
947
948
949
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 946

class SearchLimits
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

Returns Optional. The maximum number of processes to return per link. The default value is 0 and the maximum value is 100. If this value is non-zero, the response will contain process names for the links. To retrieve full process details in the response, include links.processes.process in the FieldMask.

Returns:

  • (::Integer)

    Optional. The maximum number of processes to return per link. The default value is 0 and the maximum value is 100. If this value is non-zero, the response will contain process names for the links. To retrieve full process details in the response, include links.processes.process in the FieldMask.



946
947
948
949
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 946

class SearchLimits
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#max_results::Integer

Returns Optional. The maximum number of links to return in the response. The default value is 1_000 and the maximum value is 10_000.

Returns:

  • (::Integer)

    Optional. The maximum number of links to return in the response. The default value is 1_000 and the maximum value is 10_000.



946
947
948
949
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 946

class SearchLimits
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end