Class: Google::Cloud::DataCatalog::Lineage::V1::UpdateProcessRequest
- Inherits:
-
Object
- Object
- Google::Cloud::DataCatalog::Lineage::V1::UpdateProcessRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb
Overview
Request message for UpdateProcess.
Instance Attribute Summary collapse
-
#allow_missing ⇒ ::Boolean
Optional.
-
#process ⇒ ::Google::Cloud::DataCatalog::Lineage::V1::Process
Required.
-
#request_id ⇒ ::String
Optional.
-
#update_mask ⇒ ::Google::Protobuf::FieldMask
Optional.
Instance Attribute Details
#allow_missing ⇒ ::Boolean
Returns Optional. If set to true and the process is not found, the request inserts it.
336 337 338 339 |
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 336 class UpdateProcessRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#process ⇒ ::Google::Cloud::DataCatalog::Lineage::V1::Process
Returns Required. The lineage process to update.
The process's name field is used to identify the process to update.
336 337 338 339 |
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 336 class UpdateProcessRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. A unique identifier for this request. Restricted to 36 ASCII
characters. A random UUID is recommended. This request is idempotent only
if a request_id is provided.
336 337 338 339 |
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 336 class UpdateProcessRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_mask ⇒ ::Google::Protobuf::FieldMask
Returns Optional. The list of fields to update. Currently not used. The whole message is updated.
336 337 338 339 |
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 336 class UpdateProcessRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |