Class: Google::Cloud::DataCatalog::Lineage::V1::UpdateRunRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb

Overview

Request message for UpdateRun.

Instance Attribute Summary collapse

Instance Attribute Details

#allow_missing::Boolean

Returns Optional. If set to true and the run is not found, the request creates it.

Returns:

  • (::Boolean)

    Optional. If set to true and the run is not found, the request creates it.



438
439
440
441
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 438

class UpdateRunRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#run::Google::Cloud::DataCatalog::Lineage::V1::Run

Returns Required. The lineage run to update.

The run's name field is used to identify the run to update.

Format: projects/{project}/locations/{location}/processes/{process}/runs/{run}.

Returns:

  • (::Google::Cloud::DataCatalog::Lineage::V1::Run)

    Required. The lineage run to update.

    The run's name field is used to identify the run to update.

    Format: projects/{project}/locations/{location}/processes/{process}/runs/{run}.



438
439
440
441
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 438

class UpdateRunRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask::Google::Protobuf::FieldMask

Returns Optional. The list of fields to update. Currently not used. The whole message is updated.

Returns:



438
439
440
441
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 438

class UpdateRunRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end