Class: Google::Cloud::DataCatalog::Lineage::V1::BatchSearchLinkProcessesRequest
- Inherits:
-
Object
- Object
- Google::Cloud::DataCatalog::Lineage::V1::BatchSearchLinkProcessesRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb
Overview
Request message for BatchSearchLinkProcesses.
Instance Attribute Summary collapse
-
#links ⇒ ::Array<::String>
Required.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#links ⇒ ::Array<::String>
Returns Required. An array of links to check for their associated LineageProcesses.
The maximum number of items in this array is 100.
If the request contains more than 100 links, it returns the
INVALID_ARGUMENT error.
Format: projects/{project}/locations/{location}/links/{link}.
734 735 736 737 |
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 734 class BatchSearchLinkProcessesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. The maximum number of processes to return in a single page of the response. A page may contain fewer results than this value.
734 735 736 737 |
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 734 class BatchSearchLinkProcessesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. The page token received from a previous
BatchSearchLinkProcesses call. Use it to get the next page.
When requesting subsequent pages of a response, remember that all parameters must match the values you provided in the original request.
734 735 736 737 |
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 734 class BatchSearchLinkProcessesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The project and location where you want to search.
734 735 736 737 |
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 734 class BatchSearchLinkProcessesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |