Class: Google::Cloud::DataCatalog::Lineage::V1::LineageLink
- Inherits:
-
Object
- Object
- Google::Cloud::DataCatalog::Lineage::V1::LineageLink
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb
Overview
Lineage link between two entities.
Defined Under Namespace
Classes: DependencyInfo, LineageProcess
Instance Attribute Summary collapse
-
#dependency_info ⇒ ::Array<::Google::Cloud::DataCatalog::Lineage::V1::LineageLink::DependencyInfo>
Describes how the target entity is dependent on the source entity.
-
#depth ⇒ ::Integer
Depth of the current link in the graph starting from 1.
-
#location ⇒ ::String
The location where the LineageEvent that created the link is stored.
-
#processes ⇒ ::Array<::Google::Cloud::DataCatalog::Lineage::V1::LineageLink::LineageProcess>
Processes metadata associated with the link.
-
#source ⇒ ::Google::Cloud::DataCatalog::Lineage::V1::EntityReference
The entity that is the source of this link.
-
#target ⇒ ::Google::Cloud::DataCatalog::Lineage::V1::EntityReference
The entity that is the target of this link.
Instance Attribute Details
#dependency_info ⇒ ::Array<::Google::Cloud::DataCatalog::Lineage::V1::LineageLink::DependencyInfo>
Returns Describes how the target entity is dependent on the source entity.
864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 |
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 864 class LineageLink include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Process metadata for the link. # @!attribute [rw] process # @return [::Google::Cloud::DataCatalog::Lineage::V1::Process] # Process that created the link. class LineageProcess include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Dependency info describes how one entity is dependent on another. # @!attribute [rw] dependency_type # @return [::Google::Cloud::DataCatalog::Lineage::V1::DependencyType] # The type of dependency. class DependencyInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#depth ⇒ ::Integer
Returns Depth of the current link in the graph starting from 1.
864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 |
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 864 class LineageLink include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Process metadata for the link. # @!attribute [rw] process # @return [::Google::Cloud::DataCatalog::Lineage::V1::Process] # Process that created the link. class LineageProcess include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Dependency info describes how one entity is dependent on another. # @!attribute [rw] dependency_type # @return [::Google::Cloud::DataCatalog::Lineage::V1::DependencyType] # The type of dependency. class DependencyInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#location ⇒ ::String
Returns The location where the LineageEvent that created the link is stored.
864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 |
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 864 class LineageLink include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Process metadata for the link. # @!attribute [rw] process # @return [::Google::Cloud::DataCatalog::Lineage::V1::Process] # Process that created the link. class LineageProcess include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Dependency info describes how one entity is dependent on another. # @!attribute [rw] dependency_type # @return [::Google::Cloud::DataCatalog::Lineage::V1::DependencyType] # The type of dependency. class DependencyInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#processes ⇒ ::Array<::Google::Cloud::DataCatalog::Lineage::V1::LineageLink::LineageProcess>
Returns Processes metadata associated with the link.
864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 |
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 864 class LineageLink include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Process metadata for the link. # @!attribute [rw] process # @return [::Google::Cloud::DataCatalog::Lineage::V1::Process] # Process that created the link. class LineageProcess include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Dependency info describes how one entity is dependent on another. # @!attribute [rw] dependency_type # @return [::Google::Cloud::DataCatalog::Lineage::V1::DependencyType] # The type of dependency. class DependencyInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#source ⇒ ::Google::Cloud::DataCatalog::Lineage::V1::EntityReference
Returns The entity that is the source of this link.
864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 |
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 864 class LineageLink include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Process metadata for the link. # @!attribute [rw] process # @return [::Google::Cloud::DataCatalog::Lineage::V1::Process] # Process that created the link. class LineageProcess include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Dependency info describes how one entity is dependent on another. # @!attribute [rw] dependency_type # @return [::Google::Cloud::DataCatalog::Lineage::V1::DependencyType] # The type of dependency. class DependencyInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#target ⇒ ::Google::Cloud::DataCatalog::Lineage::V1::EntityReference
Returns The entity that is the target of this link.
864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 |
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 864 class LineageLink include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Process metadata for the link. # @!attribute [rw] process # @return [::Google::Cloud::DataCatalog::Lineage::V1::Process] # Process that created the link. class LineageProcess include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Dependency info describes how one entity is dependent on another. # @!attribute [rw] dependency_type # @return [::Google::Cloud::DataCatalog::Lineage::V1::DependencyType] # The type of dependency. class DependencyInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |