Class: Google::Cloud::DataCatalog::Lineage::V1::Link
- Inherits:
-
Object
- Object
- Google::Cloud::DataCatalog::Lineage::V1::Link
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb
Overview
Links represent the data flow between source (upstream) and target (downstream) assets in transformation pipelines.
Links are created when LineageEvents record data transformation between related assets.
Defined Under Namespace
Classes: DependencyInfo
Instance Attribute Summary collapse
-
#dependency_info ⇒ ::Array<::Google::Cloud::DataCatalog::Lineage::V1::Link::DependencyInfo>
Optional.
-
#end_time ⇒ ::Google::Protobuf::Timestamp
The end of the last event establishing this link.
-
#name ⇒ ::String
readonly
Output only.
-
#source ⇒ ::Google::Cloud::DataCatalog::Lineage::V1::EntityReference
The pointer to the entity that is the source of this link.
-
#start_time ⇒ ::Google::Protobuf::Timestamp
The start of the first event establishing this link.
-
#target ⇒ ::Google::Cloud::DataCatalog::Lineage::V1::EntityReference
The pointer to the entity that is the target of this link.
Instance Attribute Details
#dependency_info ⇒ ::Array<::Google::Cloud::DataCatalog::Lineage::V1::Link::DependencyInfo>
Returns Optional. The dependency info of the link (applies only to column level links).
694 695 696 697 698 699 700 701 702 703 704 705 706 |
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 694 class Link include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Dependency info describes how one entity depends on another. # @!attribute [rw] dependency_type # @return [::Google::Cloud::DataCatalog::Lineage::V1::DependencyType] # The type of dependency. class DependencyInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#end_time ⇒ ::Google::Protobuf::Timestamp
Returns The end of the last event establishing this link.
694 695 696 697 698 699 700 701 702 703 704 705 706 |
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 694 class Link include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Dependency info describes how one entity depends on another. # @!attribute [rw] dependency_type # @return [::Google::Cloud::DataCatalog::Lineage::V1::DependencyType] # The type of dependency. class DependencyInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String (readonly)
Returns Output only. Immutable. The name of the link. Format:
projects/{project}/locations/{location}/links/{link}.
694 695 696 697 698 699 700 701 702 703 704 705 706 |
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 694 class Link include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Dependency info describes how one entity depends on another. # @!attribute [rw] dependency_type # @return [::Google::Cloud::DataCatalog::Lineage::V1::DependencyType] # The type of dependency. class DependencyInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#source ⇒ ::Google::Cloud::DataCatalog::Lineage::V1::EntityReference
Returns The pointer to the entity that is the source of this link.
694 695 696 697 698 699 700 701 702 703 704 705 706 |
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 694 class Link include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Dependency info describes how one entity depends on another. # @!attribute [rw] dependency_type # @return [::Google::Cloud::DataCatalog::Lineage::V1::DependencyType] # The type of dependency. class DependencyInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#start_time ⇒ ::Google::Protobuf::Timestamp
Returns The start of the first event establishing this link.
694 695 696 697 698 699 700 701 702 703 704 705 706 |
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 694 class Link include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Dependency info describes how one entity depends on another. # @!attribute [rw] dependency_type # @return [::Google::Cloud::DataCatalog::Lineage::V1::DependencyType] # The type of dependency. class DependencyInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#target ⇒ ::Google::Cloud::DataCatalog::Lineage::V1::EntityReference
Returns The pointer to the entity that is the target of this link.
694 695 696 697 698 699 700 701 702 703 704 705 706 |
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 694 class Link include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Dependency info describes how one entity depends on another. # @!attribute [rw] dependency_type # @return [::Google::Cloud::DataCatalog::Lineage::V1::DependencyType] # The type of dependency. class DependencyInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |