Class: Google::Cloud::DataCatalog::Lineage::V1::OperationMetadata
- Inherits:
-
Object
- Object
- Google::Cloud::DataCatalog::Lineage::V1::OperationMetadata
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb
Overview
Metadata describing the operation.
Defined Under Namespace
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#end_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#operation_type ⇒ ::Google::Cloud::DataCatalog::Lineage::V1::OperationMetadata::Type
readonly
Output only.
-
#resource ⇒ ::String
readonly
Output only.
-
#resource_uuid ⇒ ::String
readonly
Output only.
-
#state ⇒ ::Google::Cloud::DataCatalog::Lineage::V1::OperationMetadata::State
readonly
Output only.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The timestamp of the operation submission to the server.
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 221 class OperationMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An enum with the state of the operation. module State # Unused. STATE_UNSPECIFIED = 0 # The operation has been created but is not yet started. PENDING = 1 # The operation is underway. RUNNING = 2 # The operation completed successfully. SUCCEEDED = 3 # The operation is no longer running and did not succeed. FAILED = 4 end # Type of the long running operation. module Type # Unused. TYPE_UNSPECIFIED = 0 # The resource deletion operation. DELETE = 1 # The resource creation operation. CREATE = 2 end end |
#end_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The timestamp of the operation termination, regardless of its success. This field is unset if the operation is still ongoing.
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 221 class OperationMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An enum with the state of the operation. module State # Unused. STATE_UNSPECIFIED = 0 # The operation has been created but is not yet started. PENDING = 1 # The operation is underway. RUNNING = 2 # The operation completed successfully. SUCCEEDED = 3 # The operation is no longer running and did not succeed. FAILED = 4 end # Type of the long running operation. module Type # Unused. TYPE_UNSPECIFIED = 0 # The resource deletion operation. DELETE = 1 # The resource creation operation. CREATE = 2 end end |
#operation_type ⇒ ::Google::Cloud::DataCatalog::Lineage::V1::OperationMetadata::Type (readonly)
Returns Output only. The type of the operation being performed.
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 221 class OperationMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An enum with the state of the operation. module State # Unused. STATE_UNSPECIFIED = 0 # The operation has been created but is not yet started. PENDING = 1 # The operation is underway. RUNNING = 2 # The operation completed successfully. SUCCEEDED = 3 # The operation is no longer running and did not succeed. FAILED = 4 end # Type of the long running operation. module Type # Unused. TYPE_UNSPECIFIED = 0 # The resource deletion operation. DELETE = 1 # The resource creation operation. CREATE = 2 end end |
#resource ⇒ ::String (readonly)
Returns Output only. The relative name of the resource being operated on.
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 221 class OperationMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An enum with the state of the operation. module State # Unused. STATE_UNSPECIFIED = 0 # The operation has been created but is not yet started. PENDING = 1 # The operation is underway. RUNNING = 2 # The operation completed successfully. SUCCEEDED = 3 # The operation is no longer running and did not succeed. FAILED = 4 end # Type of the long running operation. module Type # Unused. TYPE_UNSPECIFIED = 0 # The resource deletion operation. DELETE = 1 # The resource creation operation. CREATE = 2 end end |
#resource_uuid ⇒ ::String (readonly)
Returns Output only. The UUID of the resource being operated on.
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 221 class OperationMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An enum with the state of the operation. module State # Unused. STATE_UNSPECIFIED = 0 # The operation has been created but is not yet started. PENDING = 1 # The operation is underway. RUNNING = 2 # The operation completed successfully. SUCCEEDED = 3 # The operation is no longer running and did not succeed. FAILED = 4 end # Type of the long running operation. module Type # Unused. TYPE_UNSPECIFIED = 0 # The resource deletion operation. DELETE = 1 # The resource creation operation. CREATE = 2 end end |
#state ⇒ ::Google::Cloud::DataCatalog::Lineage::V1::OperationMetadata::State (readonly)
Returns Output only. The current operation state.
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 221 class OperationMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An enum with the state of the operation. module State # Unused. STATE_UNSPECIFIED = 0 # The operation has been created but is not yet started. PENDING = 1 # The operation is underway. RUNNING = 2 # The operation completed successfully. SUCCEEDED = 3 # The operation is no longer running and did not succeed. FAILED = 4 end # Type of the long running operation. module Type # Unused. TYPE_UNSPECIFIED = 0 # The resource deletion operation. DELETE = 1 # The resource creation operation. CREATE = 2 end end |