Class: Google::Cloud::DataCatalog::Lineage::V1::ProcessOpenLineageRunEventRequest
- Inherits:
-
Object
- Object
- Google::Cloud::DataCatalog::Lineage::V1::ProcessOpenLineageRunEventRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb
Overview
Request message for ProcessOpenLineageRunEvent.
Instance Attribute Summary collapse
-
#open_lineage ⇒ ::Google::Protobuf::Struct
Required.
-
#parent ⇒ ::String
Required.
-
#request_id ⇒ ::String
Optional.
Instance Attribute Details
#open_lineage ⇒ ::Google::Protobuf::Struct
Returns Required. OpenLineage message following OpenLineage format: https://github.com/OpenLineage/OpenLineage/blob/main/spec/OpenLineage.json.
271 272 273 274 |
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 271 class ProcessOpenLineageRunEventRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The name of the project and its location that should own the process, run, and lineage event.
271 272 273 274 |
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 271 class ProcessOpenLineageRunEventRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. A unique identifier for this request. Restricted to 36 ASCII
characters. A random UUID is recommended. This request is idempotent only
if a request_id is provided.
271 272 273 274 |
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 271 class ProcessOpenLineageRunEventRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |