Class: Google::Cloud::DataCatalog::Lineage::V1::SearchLinksRequest
- Inherits:
-
Object
- Object
- Google::Cloud::DataCatalog::Lineage::V1::SearchLinksRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb
Overview
Request message for SearchLinks.
Instance Attribute Summary collapse
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
-
#source ⇒ ::Google::Cloud::DataCatalog::Lineage::V1::EntityReference
Optional.
-
#sources ⇒ ::Google::Cloud::DataCatalog::Lineage::V1::MultipleEntityReference
Optional.
-
#target ⇒ ::Google::Cloud::DataCatalog::Lineage::V1::EntityReference
Optional.
-
#targets ⇒ ::Google::Cloud::DataCatalog::Lineage::V1::MultipleEntityReference
Optional.
Instance Attribute Details
#page_size ⇒ ::Integer
Returns Optional. The maximum number of links to return in a single page of the response. A page may contain fewer links than this value. If unspecified, at most 10 links are returned.
Maximum value is 100; values greater than 100 are reduced to 100.
639 640 641 642 |
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 639 class SearchLinksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. The page token received from a previous SearchLinksRequest
call. Use it to get the next page.
When requesting subsequent pages of a response, remember that all parameters must match the values you provided in the original request.
639 640 641 642 |
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 639 class SearchLinksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The project and location you want search in.
639 640 641 642 |
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 639 class SearchLinksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#source ⇒ ::Google::Cloud::DataCatalog::Lineage::V1::EntityReference
Returns Optional. Send asset information in the source field to retrieve all links that lead from the specified asset to downstream assets.
Note: The following fields are mutually exclusive: source, target, sources, targets. If a field in that set is populated, all other fields in the set will automatically be cleared.
639 640 641 642 |
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 639 class SearchLinksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#sources ⇒ ::Google::Cloud::DataCatalog::Lineage::V1::MultipleEntityReference
Returns Optional. Send a list of asset information in the sources field to
retrieve all links that lead from the specified assets to downstream
assets. This field is similar to the source
source
field but allows providing multiple entities.
All entities within the MultipleEntityReference must have the same
fully_qualified_name.
Note: The following fields are mutually exclusive: sources, source, target, targets. If a field in that set is populated, all other fields in the set will automatically be cleared.
639 640 641 642 |
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 639 class SearchLinksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#target ⇒ ::Google::Cloud::DataCatalog::Lineage::V1::EntityReference
Returns Optional. Send asset information in the target field to retrieve all links that lead from upstream assets to the specified asset.
Note: The following fields are mutually exclusive: target, source, sources, targets. If a field in that set is populated, all other fields in the set will automatically be cleared.
639 640 641 642 |
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 639 class SearchLinksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#targets ⇒ ::Google::Cloud::DataCatalog::Lineage::V1::MultipleEntityReference
Returns Optional. Send a list of asset information in the targets field to
retrieve all links that lead from upstream assets to the specified
assets. This field is similar to the target
target
field but allows providing multiple entities.
All entities within the MultipleEntityReference must have the same
fully_qualified_name.
Note: The following fields are mutually exclusive: targets, source, target, sources. If a field in that set is populated, all other fields in the set will automatically be cleared.
639 640 641 642 |
# File 'proto_docs/google/cloud/datacatalog/lineage/v1/lineage.rb', line 639 class SearchLinksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |